#
# spec file for package sdcc
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sdcc
Version:        3.6.0
Release:        27.1
Summary:        Small Device C Compiler
License:        GPL-2.0+ and GPL-3.0+
Group:          Development/Languages/C and C++
Url:            http://sdcc.sourceforge.net/
Source:         http://downloads.sourceforge.net/%{name}/%{name}-src-%{version}.tar.bz2
Source1:        %{name}-rpmlintrc
Patch2:         sdcc_enable_additional_target_libs.patch
BuildRequires:  bison
BuildRequires:  boost-devel
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  gputils
BuildRequires:  libstdc++-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  python-devel
# documentation
%if 0%{?suse_version} >= 1220
BuildRequires:  latex2html
BuildRequires:  lyx
BuildRequires:  makeinfo
BuildRequires:  texlive-babel-english
%if 0%{?suse_version} > 1320
BuildRequires:  texlive-xetex-bin
%endif
BuildRequires:  texlive-dvipdfmx
BuildRequires:  texlive-fancyhdr
BuildRequires:  texlive-latex
BuildRequires:  texlive-makeindex
BuildRequires:  texlive-ulem
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(post): %install_info_prereq
Requires(preun): %install_info_prereq

%description
SDCC is a C compiler for 8051 class and similar microcontrollers.
The package includes the compiler, assemblers and linkers, a device
simulator and a core library. The processors supported (to a varying
degree) include the 8051, ds390, z80, hc08, and PIC.

%package        doc
Summary:        Documentation for the SDCC C compiler
Group:          Documentation/HTML
%if 0%{?suse_version} >= 1140
BuildArch:      noarch
%endif

%description    doc
SDCC is a C compiler for 8051 class and similar microcontrollers.
The package includes the compiler, assemblers and linkers, a device
simulator and a core library. The processors supported (to a varying
degree) include the 8051, ds390, z80, hc08, and PIC.

This package contains documentation for SDCC C compiler.

%package        libc-sources
Summary:        Small Device C Compiler
Group:          Development/Languages/C and C++
Requires:       %{name} = %{version}

%description    libc-sources
SDCC is a C compiler for 8051 class and similar microcontrollers.
The package includes the compiler, assemblers and linkers, a device
simulator and a core library. The processors supported (to a varying
degree) include the 8051, ds390, z80, hc08, and PIC.

This package contains sources for the C library and other files for
development.

%prep
%setup -q
rm support/regression/tests/bug3304184.c
%patch2 -p1

%build
CFLAGS="%{optflags} -fno-strict-aliasing" \
%configure \
    --docdir=%{_docdir}/sdcc \
    %if 0%{?suse_version} >= 1320
    --enable-doc
    %endif

make %{?_smp_mflags}

%install
%make_install

# install documentation
mkdir -p %{buildroot}%{_docdir}/%{name}/sdas
cp sdas/doc/* %{buildroot}%{_docdir}/%{name}/sdas
cp ChangeLog %{buildroot}%{_docdir}/%{name}
cp COPYING %{buildroot}%{_docdir}/%{name}

mkdir -p %{buildroot}%{_datadir}/emacs/site-lisp
mv %{buildroot}%{_bindir}/*.el %{buildroot}%{_datadir}/emacs/site-lisp

#remove useless file
rm %{buildroot}%{_docdir}/%{name}/INSTALL.txt

cp ChangeLog %{buildroot}%{_docdir}/%{name}
cp COPYING %{buildroot}%{_docdir}/%{name}

#remove strange suff (installed by mistake?)
rm -rf %{buildroot}%{_includedir}
rm -rf %{buildroot}%{_libdir}

# remove non-free libraries, see doc/README.txt: Licenses
rm -rf %{buildroot}%{_datadir}/%{name}/non-free/

# duplicates
%fdupes -s %{buildroot}%{_datadir}/%{name}/lib/src

%if 0%{?suse_version} <= 1210
find %{buildroot}%{_datadir}/%{name} -name '*.Po' -exec rm {} \;
rm -rf %{buildroot}%{_datadir}/%{name}/lib/src/pic16/*/.deps
rm -rf %{buildroot}%{_datadir}/%{name}/lib/src/pic14/libsdcc/*/.deps
rm -rf %{buildroot}%{_datadir}/%{name}/lib/src/pic14/libm/.deps
rm -rf %{buildroot}%{_datadir}/%{name}/non-free/lib/src/pic16/libdev/.deps
%endif

%post
%install_info --info-dir=%{_infodir} %{_infodir}/bfd.info.gz

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/bfd.info.gz


%files
%defattr(-,root,root)
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/ChangeLog
%{_docdir}/%{name}/COPYING
%{_docdir}/%{name}/README.txt
%{_bindir}/*
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/include
%{_datadir}/%{name}/lib
%exclude %{_datadir}/%{name}/lib/src
%dir %{_datadir}/emacs/site-lisp
%{_datadir}/emacs/site-lisp/*.el
%{_infodir}/bfd.info.gz

%files libc-sources
%defattr(-,root,root)
%{_datadir}/%{name}/lib/src

%files doc
%defattr(-,root,root)
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/ucsim
%{_docdir}/%{name}/sdas
%if 0%{?suse_version} >= 1320
%{_docdir}/%{name}/sdccman.pdf
%endif

%changelog
* Tue Sep  6 2016 wk@ire.pw.edu.pl
- Fixed info file uninstall
* Mon Sep  5 2016 wk@ire.pw.edu.pl
- Update to version 3.5.0
  * Merged upstream binutils 2.25
  * New memory management with lower overhead
  * Changed default language dialect to --std-sdcc11
  * Diagnostic for missing type specifier: No implicit int outside of C90 mode anymore
  * C11 generic selections
  * char type is now unsigned by default (old behaviour can be restored using --fsigned-char)
  * Character constants are now of type int instead of char.
  * ISO C95 and ISO C11 wide character constants
  * ISO C95 and ISO C11 wide string literals
  * Basic standard library support for wide characters: c16rtomb(), mbrtoc16(), mbsinit(), mbtowc(), mbrlen(), mbrtoc32, c32rtomb(), mbrtowc(), wcrtomb(), mblen(), wctomb()
  * Treat all ports the same in the manual (i.e. mcs51-specific stuff is now clearly described as such)
  * Reorganized interrupt handling for z80, z180, r2k, r3ka, tlcs90, gbz80 backends
  * Workaround for stm8 division hardware bug
  * ELF/DWARF support for stm8
  * Output symbol table for ELF
  * pic16 port now uses standard-compliant crt0iz that initializes static and globals to 0 by default
- Numerous feature requests and bug fixes are included as well.
- Removed patch sdcc_add_ppc64le_suse_support.patch (applied upstream)
- Modified patch sdcc_enable_additional_target_libs.patch
* Tue Aug 16 2016 dimstar@opensuse.org
- BuildRequire texlive-xetex-bin in plus in openSUSE Tumbleweed in
  order to workaround boo#992360.
* Fri Oct 30 2015 tobias.johannes.klausmann@mni.thm.de
- Build additional libraries sdcc can link against
- Add patch sdcc_enable_additional_target_libs.patch
* Tue Aug 25 2015 dmitry_r@opensuse.org
- Add _constraints file, 3 Gb of memory are required
* Tue Aug 18 2015 normand@linux.vnet.ibm.com
- new patch to build on ppc64le
  sdcc_add_ppc64le_suse_support.patch
* Fri Jun 26 2015 dmitry_r@opensuse.org
- Update to version 3.5.0
  * Changed default language dialect from --std-sdcc89 to --std-sdcc99
  * Reorganized and updated manual
  * Reduced memory consumption (most noticeable for high --max-allocs-per-node)
  * Faster compilation for stm8 (most noticeable for high --max-allocs-per-node)
  * atoll() function for conversion of strings to long long
  * __z88dk_fastcall and __z88dk_callee calling conventions for more
    efficient function calls and better compability with z88dk
  * --lospre-unsafe-read renamed to --allow-unsafe-read
- Drop obsolete
  * sdcc-remove-strndup.patch
  * sdcc-libiberty.patch
* Sun Nov 30 2014 wk@ire.pw.edu.pl
- Fixed build for Tumbleweed and Factory by adding patch
    sdcc-remove-strndup.patch
- added patch sdcc-libiberty.patch
* Thu Jul 31 2014 dmitry_r@opensuse.org
- Change package license to GPL-2.0+ and GPL-3.0+ [bnc#889723]
* Mon Jul 28 2014 dmitry_r@opensuse.org
- spec file cleanup
- Remove non-free libraries
- Move libc sources to separate package
* Thu Oct  4 2012 Wojciech Kazubski <wk@ire.pw.edu.pl> -3.2.0-13
- update to 3.2.0
* Mon Sep  3 2012 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to 3.1.0
* Fri Nov 30 2007 Tuukka Pasanen <rpms@ilmi.fi>
- New version
* Tue Feb 20 2007 Tuukka Pasanen <rpms@ilmi.fi>
- Initial build
